********************************************************************************
* life_expectancy_pm25.do
* Purpose: 
*	This file imports, cleans and analyzes EPA and Census data to measure the 
*   decline in PM2.5 pollution after the Clean Air Act of `year'. 
*
* Instructions: 
*	Change into local directory.

********************************************************************************

/******* preamble *******/ 

set more off, permanently
clear 
capture log close 
cd "C:\Users\Hp\Desktop\AQLI Project\AQLI\data-raw\figure17AnnualReport\CleanAirAct" // set as your working directory 

local latestyear = 2020

/****** I. Clean EPA monitor data ******/
local years "2014 2015 2016 2017 2018 2019 2020"

*Read in data up to and including 2014. 
insheet using "EPA/pm_annual_summary.csv", clear
drop summaryindicator
outsheet using  "EPA/annual_conc_by_monitor_2014.csv", replace

*There's separate downloaded data for 2015 onwards. Clean and merge with 2014 and earlier years.
foreach y of local years{
	insheet using "EPA/annual_conc_by_monitor_`y'.csv", clear
	keep if parametercode == 11101 | parametercode == 81102 | parametercode == 88502 | parametercode == 88101
	/*drop unnecessary variables*/
	drop address localsitename stmaxvalue stmaxdatetime certificationindicator eventtype unitsofmeasure
	/*generate a string for state id, add leading zeroes*/ 
	tostring statecode, replace format("%02.0f")

	/*generate a string for county id, add leading zeroes*/ 
	tostring countycode, replace format("%03.0f")

	/*generate location variable = state-county fips*/
	gen location = statecode + countycode 

	/*make year a string*/
	tostring year, replace 

	/*generate name of county*/
	gen name = countyname + ", " + statename 
	order name
	order location  

	/*per EPA guidance: only keep monitor-year observations where at least 75% 
	of required number of observations were actually taken */
	keep if observationpercent >= 75 

	/* generate a string that links the parameter code to an English definition */
	gen pollutant_code = "TSP" if parametercode == 11101
	replace pollutant_code = "PM10" if parametercode == 81102
	replace pollutant_code = "PM25" if parametercode == 88502 | parametercode == 88101

	/* collapse by county, weighting by the number of observations */
	collapse validdaycount-arithmeticmean [aweight = observationcount], by(year name location pollutant_code)

	/* reshape pollutant data from long to wide */ 
	reshape wide validdaycount-arithmeticmean, i(name location year) j(pollutant_code) string
	save "EPA/pm_`y'.dta", replace
}

use "EPA/pm_2014.dta", clear
drop if year=="2015"

foreach y of local years {
	append using "EPA/pm_`y'.dta"
}

replace location = location[_n-1] if missing(location) & name == name[_n-1]
drop if missing(location)
sort location year 

/********** II. Impute PM2.5 using PM10/PM2.5, TSP/PM2.5, PM10/TSP ratios ********/

/* generate a ratio, at the county level, of TSP to PM10 */
gen cty_tsp_pm10 = arithmeticmeanTSP / arithmeticmeanPM10

/* generate the average PM10 to TSP ratio over measured years, within a county */ 
sort location year 
egen avg_tsp_pm10_ratio = mean(cty_tsp_pm10), by(location) 

/* generate a ratio, at the county level, of PM10 to PM2.5 */
gen cty_pm10_pm25 = arithmeticmeanPM10 / arithmeticmeanPM25

/* get average PM10 to PM2.5 ratio over measured years, within a county */ 
sort location year 
egen avg_pm10_pm25_ratio = mean(cty_pm10_pm25), by(location)

/* generate a ratio, at the county level, of TSP to PM2.5 */
/* replace with PM10/PM2.5 / (PM10/TSP) if TSP/PM2.5 never observed */
gen cty_tsp_pm25 = arithmeticmeanTSP / arithmeticmeanPM25

/* get average PM2.5 to TSP ratio over measured years, within a county */
/* replace with PM2.5/PM10 * PM10/TSP if PM2.5/TSP never observed */ 
sort location year 
egen avg_tsp_pm25_ratio = mean(cty_tsp_pm25), by(location)
replace avg_tsp_pm25_ratio = avg_pm10_pm25_ratio*avg_tsp_pm10_ratio if avg_tsp_pm25_ratio==.

/*** III. Impute PM2.5 for 5-year window around 1970 ***/ 
/* impute PM2.5 from mean county ratios of TSP*/ 
gen PM25_tsp_cty = arithmeticmeanPM25
replace PM25_tsp_cty = arithmeticmeanTSP / avg_tsp_pm25_ratio if ///
(PM25_tsp_cty == . ) 

/* drop unnecessary variables */
drop validdaycountPM10-numobsbelowmdlPM25 validdaycountTSP-avg_tsp_pm25_ratio

/* generate "pre-period" window of PM2.5 in 1970*/

/* convert year to a number */
destring year, replace 

/*start at the lowest year and progress to the highest year*/
forvalue var = 1968/1972{

/* generate a variable for PM2.5 for in that year */ 
gen PM25_tsp_cty_`var' = PM25_tsp_cty if year == `var'

/* generate a variable, of that particular year's pollution, for each year for that location */
egen PM25_tsp_cty_`var'_county = mean(PM25_tsp_cty_`var'), by(location)

/*replace the overall PM2.5 at the year as the total of the county, by year */
replace PM25_tsp_cty_`var' = PM25_tsp_cty_`var'_county

/*drop clutter*/
drop PM25_tsp_cty_`var'_county
}

/*take the mean of all the years available from 1968-1972 */
egen pm25_1970_epa = rowmean(PM25_tsp_cty_1968-PM25_tsp_cty_1972)

/*replace as . if missing*/
replace pm25_1970_epa = . if pm25_1970_epa == 0 

/*drop clutter*/
drop PM25_tsp_cty_1968-PM25_tsp_cty_1972


/*** IV. Satellite adjustment ***/
*save monitor-based 1970 imputed values along with directly measured PM2.5
keep if arithmeticmeanPM25 != . & pm25_1970_epa != . & year>=1998
replace name = "Anchorage, Alaska" if name=="Anchorage , Alaska"
save "intermediate/county_sat_mon_ratios", replace

*merge in AQLI satellite data
use "AQLI/us_county_satellite", clear
keep objectid_hover name_1 name_2 pm*
*clean data so that names match with EPA data for merging
replace name_1 = "District Of Columbia" if name_1 == "District of Columbia"
replace name_2 = "Hopewell City" if name_2 == "Hopewell" & name_1=="Virginia"
replace name_2 = "Hampton City" if name_2 == "Hampton" & name_1 == "Virginia"
replace name_2 = "Norfolk City" if name_2 == "Norfolk" & name_1 == "Virginia"
replace name_2 = "St. Joseph" if name_2=="Saint Joseph" & name_1 == "Indiana"
replace name_2 = "Baltimore (City)" if name_2 == "Baltimore" 
replace name_2 = "St. Louis City" if name_2 == "Saint Louis" & name_1 == "Missouri" 
gen name = name_2 + ", " + name_1
drop name_1 name_2
reshape long pm, i(name) j(year)
rename pm pm25_aqli
merge 1:m name year using "intermediate/county_sat_mon_ratios", keep(3) nogen

*generate satellite-to-monitor ratio by county
gen yrratio = pm25_aqli/arithmeticmeanPM25
egen avgratio = mean(yrratio), by(objectid_hover)
collapse avgratio pm25_1970_epa, by(objectid_hover name location)
save "intermediate/county_sat_mon_ratios", replace

*calculate satellite-adjusted 1970 imputed PM2.5
gen pm25_1970_aqli = avgratio*pm25_1970_epa
tempfile pm25_1970_aqli_county
save `"`pm25_1970_aqli_county'"'

/*** V. Lifeyears ***/
*We are calculating life expectancy gained due to PM reductions, between 1970-latest year
keep location objectid_hover name pm25_1970_aqli
merge 1:1 objectid_hover using "AQLI/us_county_satellite", 
keep if pm25_1970_aqli != .
keep location objectid_hover country name_1 name_2 population llpp_who5_`latestyear' pm25_1970_aqli pm`latestyear' pm1998
order location objectid_hover country name_1 name_2 population pm25_1970_aqli pm`latestyear' pm1998

gen lifeyears_saved = (pm25_1970_aqli-pm`latestyear')*.098 
replace lifeyears_saved = . if pm25_1970_aqli == .

sort name_1 name_2
*save county-level results
* intermediate file contains the object hover ids
save "intermediate/pm25_1970_lys_foraqli", replace

/*** VIII. Calculate statistics ***/
*population covered - counties
egen total_pop = total(population)
gen total_lifeyears = lifeyears_saved*population 

*total lifeyears across population covered
egen total_pop_lifeyears = total(total_lifeyears)

*average lifeyears over population covered
gen avg_lifeyears = total_pop_lifeyears/total_pop

*pop-weighted 1970 PM2.5
gen poppollution1970 = population*pm25_1970_aqli/total_pop
egen avgpollution1970 = total(poppollution1970)

*pop-weighted 1998 PM2.5
gen poppollution1998 = population*pm1998/total_pop
egen avgpollution1998 = total(poppollution1998)

*pop-weighted PM2.5 in latest year
gen poppollution`latestyear' = population*pm`latestyear'/total_pop
egen avgpollution`latestyear' = total(poppollution`latestyear')

*percent change in PM2.5, 1970-latest year
gen percentchange1970`latestyear' = 1-avgpollution`latestyear'/avgpollution1970

*change between 1998-latest year as proportion of change between 1970-latest year
gen propofchange1998`latestyear' = (avgpollution1998-avgpollution`latestyear')/(avgpollution1970-avgpollution`latestyear')

*drop intermediate variables
drop poppollution1970 poppollution1998 poppollution`latestyear'

* save the intermediate dataset (including objectid_hover): providing statistics at county levl
save "final/county_pm25_foraqli_stats", replace
export delimited "final/county_pm25_foraqli_stats", replace


*make file of just these stats
collapse (first) total_pop total_pop_lifeyears avg_lifeyears avgpollution1970 avgpollution1998 avgpollution`latestyear' percentchange1970`latestyear' propofchange1998`latestyear'
save "final/hover_pm25_foraqli_stats", replace
export delimited "final/hover_pm25_foraqli_stats.csv", replace
